@@ -306,11 +306,16 @@ show_latex_error = function(
   }
   if (length(m)) {
     message(paste(m, collapse = '\n'))
-    check_inline_math(m, file)
+    latex_hints(m, file)
     stop(e, ' See ', logfile, ' for more info.', call. = FALSE)
   } else if (force) stop(e, call. = FALSE)
 }
 
+latex_hints = function(x, f) {
+  check_inline_math(x, f)
+  check_unicode(x)
+}
+
 check_inline_math = function(x, f) {
   r = 'l[.][0-9]+\\s*|\\s*[0-9.]+\\\\times.*'
   if (!any('! Missing $ inserted.' == x) || !length(i <- grep(r, x))) return()
@@ -324,6 +329,13 @@ check_inline_math = function(x, f) {
   )
 }
 
+check_unicode = function(x) {
+  if (length(grep('! Package inputenc Error: Unicode character', x))) message(
+    'Try other LaTeX engines instead (e.g., xelatex) if you are using pdflatex. ',
+    'For R Markdown users, see https://bookdown.org/yihui/rmarkdown/pdf-document.html'
+  )
+}
+
 # whether a LaTeX log file contains LaTeX or package (e.g. babel) warnings
 latex_warning = function(file, show = FALSE) {
   if (!file.exists(file)) return()
